@@ -1,6 +1,7 @@
 from typing import Dict, List
 
 import jupyter_server.serverapp
+from jupyter_server.utils import url_path_join
 
 from ._version import __version__  # noqa:F401
 from .ydoc import YDocWebSocketHandler
@@ -11,5 +12,7 @@ def _jupyter_server_extension_points() -> List[Dict[str, str]]:
 
 
 def _load_jupyter_server_extension(serverapp: jupyter_server.serverapp.ServerApp) -> None:
-    handlers = [(r"/api/yjs/(.*)", YDocWebSocketHandler)]
-    serverapp.web_app.add_handlers(".*$", handlers)
+    web_app = serverapp.web_app
+    host_pattern = ".*$"
+    route_pattern = url_path_join(web_app.settings["base_url"], r"/api/yjs/(.*)")
+    web_app.add_handlers(host_pattern, [(route_pattern, YDocWebSocketHandler)])
